==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/hr.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Krugovi",
    "Circles' files" : "Datoteke krugova",
    "Select circles to filter by" : "Odaberite krugove koje želite filtrirati",
    "No circles found" : "Nije pronađen nijedan krug",
    "Please select circles to filter by" : "Odaberite krugove koje želite filtrirati",
    "No files found for the selected circles" : "Nije pronađena nijedna datoteka za odabrane krugove",
    "You created the circle {circle}" : "Stvorili ste krug {circle}",
    "{author} created the circle {circle}" : "{author} je stvorio krug {circle}",
    "You deleted {circle}" : "Izbrisali ste {circle}",
    "{author} deleted {circle}" : "{author} je izbrisao {circle}",
    "You linked {group} to {circle}" : "Povezali ste {group} s {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} je povezao {group} s {circle}",
    "You unlinked {group} from {circle}" : "Prekinuli ste vezu {group} s {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} je prekinuo vezu {group} s {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Promijenili ste razinu povezane grupe {group} u {circle} na %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} je promijenio razinu povezane grupe {group} u {circle} na %1$s",
    "You sent a request to link {circle} with {remote}" : "Poslali ste zahtjev za povezivanje {circle} s {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{autor} je poslao zahtjev za povezivanje {circle} s {remote}",
    "{remote} requested a link with {circle}" : "{remote} je zatražio vezu s {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Zahtjev za povezivanjem {circle} s {remote} je odbijen",
    "The request to link {remote} with {circle} has been canceled remotely" : "Zahtjev za povezivanjem {remote} s {circle} je daljinski otkazan",
    "The request to link {circle} with {remote} has been accepted" : "Zahtjev za povezivanjem {circle} s {remote} je prihvaćen",
    "You dismissed the request to link {remote} with {circle}" : "Zanemarili ste zahtjev za povezivanjem {remote} s {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} je zanemario zahtjev za povezivanjem {remote} s {circle}",
    "You canceled the request to link {circle} with {remote}" : "Otkazali ste zahtjev za povezivanjem {circle} s {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{autor} je otkazao zahtjev za povezivanjem {circle} s {remote}",
    "You accepted the request to link {remote} with {circle}" : "Prihvatili ste zahtjev za povezivanjem {remote} s {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} je prihvatio zahtjev za povezivanjem {remote} s {circle}",
    "A link between {circle} and {remote} is now up and running" : "Veza između {circle} i {remote} je inicijalizirana",
    "The link between {circle} and {remote} has been shutdown remotely" : "Veza između {circle} i {remote} isključena je daljinski",
    "You closed the link between {circle} and {remote}" : "Zatvorili ste vezu između {circle} i {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} je zatvorio vezu između {circle} i {remote}",
    "You joined {circle}" : "Pridružili ste se {circle}",
    "{member} joined {circle}" : "{member} se pridružio {circle}",
    "You accepted the invitation to join {circle}" : "Prihvatili ste pozivnicu za pridruživanje {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} je prihvatio pozivnicu za pridruživanje {circle}",
    "You added {member} as member to {circle}" : "Dodali ste {member} kao člana u {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vas je dodao kao člana u {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} je dodao {member} kao člana u {circle}",
    "You added {external} to {circle}" : "Dodali ste {external} u {circle}",
    "{external} has been added to {circle} by {author}" : "{author} je dodao {external} u {circle}",
    "You accepted {member}'s request to join {circle}" : "Prihvatili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaš zahtjev za pridruživanje {circle} prihvatio je {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} je prihvatio zahtjev {member} za pridruživanje {circle}",
    "You left {circle}" : "Napustili ste {circle}",
    "{member} left {circle}" : "{member} je napustio {circle}",
    "You declined the invitation to join {circle}" : "Odbili ste poziv za pridruživanje {circle}",
    "{member} declined an invitation to join {circle}" : "{član} je odbio poziv za pridruživanje {circle}",
    "You cancelled your request to join {circle}" : "Otkazali ste zahtjev za pridruživanje {circle}",
    "{member} cancelled his request to join {circle}" : "{member} je otkazao svoj zahtjev za pridruživanje {circle}",
    "You removed {member} from {circle}" : "Uklonili ste {member} iz {circle}",
    "You have been removed from {circle} by {author}" : "{author} vas je uklonio iz {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} je uklonio {member} iz {circle}",
    "You removed {external} from {circle}" : "Uklonili ste {external} iz {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} je uklonio {external} iz {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Otkazali ste poziv {member} na sudjelovanje u {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} je otkazao vaš poziv za pridruživanje {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} je otkazao poziv {member} na sudjelovanje u {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zanemarili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} je zanemario vaš zahtjev za pridruživanje {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} je zanemario zahtjev {member} za pridruživanje {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} da se pridruži {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas je pozvao da se pridružite {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} je pozvao {member} da se pridruži {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Promijenili ste razinu {member} u {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} je promijenio vašu razinu u {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} je promijenio razinu {member} u {circle} na %1$s",
    "You sent a request to join {circle}" : "Poslali ste zahtjev za pridruživanje {circle}",
    "{member} sent a request to join {circle}" : "{member} je poslao zahtjev za pridruživanje {circle}",
    "You are the new owner of {circle}" : "Vi ste novi vlasnik {circle}",
    "{member} is the new owner of {circle}" : "{member} je novi vlasnik {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "O događajima koji se događaju u <strong>krugu</strong> čiji ste član",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Bilo koji važan događaj u <strong>krugu</strong> koji moderirate",
    "On global events happening in any <strong>Circle</strong>" : "O globalnim događajima koji pripadaju bilo kojem <strong>krugu</strong>",
    "Single" : "Jedan",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Visible" : "Vidljivo",
    "Open" : "Otvori",
    "Invite" : "Poziv",
    "Join Request" : "Zahtjev za pridruživanje",
    "Friends" : "Prijatelji",
    "Password Protected" : "Zaštićeno zaporkom",
    "No Owner" : "Nema vlasnika",
    "Hidden" : "Skriveno",
    "Backend" : "Pozadinski sustav",
    "Local" : "Lokalno",
    "Root" : "Korijen",
    "Circle Invite" : "Poziv u krug",
    "Federated" : "Udruženo",
    "Mount point" : "Točka postavljanja",
    "Nextcloud Group" : "Nextcloud grupa",
    "Email Address" : "Adresa e-pošte",
    "Contact" : "Kontakt",
    "Circle" : "Krug",
    "Nextcloud App" : "Nextcloud aplikacija",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "%s shared »%s« with you." : "%s dijeli »%s« s vama.",
    "%s shared »%s« with \"%s\"." : "%s dijeli »%s« s „%s“.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s dijeli »%2$s« s vama.\nTrebali ste već primiti poruku e-pošte s poveznicom za pristupanje.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s dijeli »%2$s« s vama. Trebali ste već primiti poruku e-pošte s poveznicom za pristupanje.",
    "Password to access »%1$s« shared to you by %2$s" : "Zaporku za pristupanje »%1$s« s vama dijeli %2$s",
    "Password to access »%s«" : "Zaporka za pristupanje »%s«",
    "It is protected with the following password:" : "Zaštićeno je sljedećom zaporkom:",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
    "Open »%s«" : "Otvori »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s dijeli više datoteka s vama.\nTrebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s dijeli više datoteka s vama. Trebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.",
    "Password to access files shared to you by %1$s" : "Zaporka za pristupanje datotekama koju s vama dijeli %1$s",
    "Password to access files" : "Zaporka za pristupanje datotekama",
    "%s shared multiple files with \"%s\"." : "%s dijeli više datoteka s „%s“.",
    "%s shared multiple files with you." : "%s dijeli više datoteka s vama.",
    "Boot up" : "Pokreni",
    "Initialisation Nextcloud" : "Inicijalizacija Nextclouda",
    "Initialisation Circles App" : "Inicijalizacija aplikacije Circles",
    "Fresh installation status" : "Status svježe instalacije",
    "Building Local Database" : "Izgradnja lokalne baze podataka",
    "Testing Basic Circle Creation" : "Ispitivanje stvaranja osnovnog kruga",
    "Adding local users and moderators" : "Dodavanje lokalnih korisnika i moderatora",
    "Circle not found" : "Krug nije pronađen",
    "Circle not found " : "Krug nije pronađen ",
    "A circle with that name exists" : "Postoji krug s tim nazivom",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Aplikaciju Krugovi ne možete upotrebljavati dok administrator ne dopusti barem jednu vrstu krugova",
    "This member does not exist" : "Ovaj član ne postoji",
    "Federated link not found" : "Udružena poveznica nije pronađena",
    "This feature is not available for personal circles" : "Ova značajka nije dostupna za osobne krugove",
    "The circle is not federated" : "Krug nije udruženi",
    "You cannot join this circle" : "Ne možete se pridružiti ovom krugu",
    "This member is not a moderator" : "Ovaj član nije moderator",
    "Insufficient privileges" : "Nedovoljne ovlasti",
    "This member is the owner of the circle" : "Ovaj član je vlasnik kruga",
    "Level cannot be changed for this type of member" : "Razina se ne može promijeniti za ovu vrstu člana",
    "You are already a member of this circle" : "Već ste član ovog kruga",
    "You have been blocked from this circle" : "Blokirani ste iz ovog kruga",
    "You are now a member of the Circle \"%2$s\"" : "Postali ste član kruga „%2$s”",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s vas je pozvao u krug „%2$s”",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s je poslao zahtjev za učlanjenje u krug „%2$s”",
    "Accept" : "Prihvati",
    "Refuse" : "Odbij",
    "Leave the circle" : "Napusti krug",
    "%s" : "%s",
    "Personal Circle" : "Osobni krug",
    "%s owned by %s" : "%s u vlasništvu %s",
    "You need a specify a type of circle" : "Trebate odrediti vrstu kruga",
    "This member is not the owner of the circle" : "Ovaj član nije vlasnik kruga",
    "This member is not an admin of the circle" : "Ovaj član nije administrator kruga",
    "Group contains too many members" : "Grupa ima previše članova",
    "This group does not exist" : "Ova grupa ne postoji",
    "This group is already linked to the circle" : "Ova je grupa već povezana s krugom",
    "You cannot edit level in a personal circle" : "Ne možete uređivati razinu u osobnom krugu",
    "Group cannot be set as owner of a circle" : "Grupa se ne može postaviti kao vlasnik kruga",
    "now" : "sada",
    "Email format is not valid" : "Format e-pošte nije važeći",
    "This contact is not available" : "Ovaj kontakt nije dostupan",
    "%s shared a file with you." : "%s dijeli datoteku s vama.",
    "This item is already shared with this circle" : "Ova se stavka već dijeli s ovim krugom",
    "Could not find share" : "Nije moguće pronaći dijeljenje",
    "Bring cloud-users closer together." : "Približite korisnike oblaka.",
    "No files in here" : "Nema datoteka",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "Nextcloud User" : "Nextcloud korisnik",
    "This user is already a member of the circle" : "Ovaj korisnik već je član kruga",
    "The user is already a member of this circle" : "Korisnik je već član ovog kruga",
    "The user has already been invited into this circle" : "Korisnik je već pozvan u ovaj krug",
    "This user does not exist" : "Ovaj korisnik ne postoji",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Krugovi omogućuju korisnicima da stvaraju vlastite grupe korisnika/kolega/prijatelja.\nTe grupe korisnika („krugove“) tada može upotrebljavati za dijeljenje bilo koja druga aplikacija."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/hr.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Izbrisali ste {circle}",
    "{author} deleted {circle}" : "{author} je izbrisao {circle}",
    "You joined {circle}" : "Pridružili ste se {circle}",
    "{member} joined {circle}" : "{member} se pridružio {circle}",
    "You accepted the invitation to join {circle}" : "Prihvatili ste pozivnicu za pridruživanje {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} je prihvatio pozivnicu za pridruživanje {circle}",
    "You added {member} as member to {circle}" : "Dodali ste {member} kao člana u {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vas je dodao kao člana u {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} je dodao {member} kao člana u {circle}",
    "You added {external} to {circle}" : "Dodali ste {external} u {circle}",
    "{external} has been added to {circle} by {author}" : "{author} je dodao {external} u {circle}",
    "You accepted {member}'s request to join {circle}" : "Prihvatili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaš zahtjev za pridruživanje {circle} prihvatio je {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} je prihvatio zahtjev {member} za pridruživanje {circle}",
    "You left {circle}" : "Napustili ste {circle}",
    "{member} left {circle}" : "{member} je napustio {circle}",
    "You declined the invitation to join {circle}" : "Odbili ste poziv za pridruživanje {circle}",
    "{member} declined an invitation to join {circle}" : "{član} je odbio poziv za pridruživanje {circle}",
    "You cancelled your request to join {circle}" : "Otkazali ste zahtjev za pridruživanje {circle}",
    "You removed {member} from {circle}" : "Uklonili ste {member} iz {circle}",
    "You have been removed from {circle} by {author}" : "{author} vas je uklonio iz {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} je uklonio {member} iz {circle}",
    "You removed {external} from {circle}" : "Uklonili ste {external} iz {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} je uklonio {external} iz {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Otkazali ste poziv {member} na sudjelovanje u {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} je otkazao vaš poziv za pridruživanje {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} je otkazao poziv {member} na sudjelovanje u {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zanemarili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} je zanemario vaš zahtjev za pridruživanje {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} je zanemario zahtjev {member} za pridruživanje {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} da se pridruži {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas je pozvao da se pridružite {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} je pozvao {member} da se pridruži {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Promijenili ste razinu {member} u {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} je promijenio vašu razinu u {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} je promijenio razinu {member} u {circle} na %1$s",
    "You sent a request to join {circle}" : "Poslali ste zahtjev za pridruživanje {circle}",
    "{member} sent a request to join {circle}" : "{member} je poslao zahtjev za pridruživanje {circle}",
    "You are the new owner of {circle}" : "Vi ste novi vlasnik {circle}",
    "{member} is the new owner of {circle}" : "{member} je novi vlasnik {circle}",
    "Shared to Circles" : "Dijeljeno u krugovima",
    "Single" : "Jedan",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Visible" : "Vidljivo",
    "Open" : "Otvori",
    "Invite" : "Poziv",
    "Friends" : "Prijatelji",
    "Password protected" : "Zaštićeno zaporkom",
    "No Owner" : "Nema vlasnika",
    "Hidden" : "Skriveno",
    "Backend" : "Pozadinski sustav",
    "Local" : "Lokalno",
    "Root" : "Korijen",
    "Federated" : "Udruženo",
    "Mount point" : "Točka postavljanja",
    "Nextcloud Group" : "Nextcloud grupa",
    "Email address" : "Adresa e-pošte",
    "Contact" : "Kontakt",
    "Circle" : "Krug",
    "Nextcloud App" : "Nextcloud aplikacija",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "%s shared »%s« with you." : "%s dijeli »%s« s vama.",
    "%s shared »%s« with \"%s\"." : "%s dijeli »%s« s „%s“.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s dijeli »%2$s« s vama.\nTrebali ste već primiti poruku e-pošte s poveznicom za pristupanje.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s dijeli »%2$s« s vama. Trebali ste već primiti poruku e-pošte s poveznicom za pristupanje.",
    "Password to access »%1$s« shared to you by %2$s" : "Zaporku za pristupanje »%1$s« s vama dijeli %2$s",
    "Password to access »%s«" : "Zaporka za pristupanje »%s«",
    "It is protected with the following password:" : "Zaštićeno je sljedećom zaporkom:",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
    "Open »%s«" : "Otvori »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s dijeli više datoteka s vama.\nTrebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s dijeli više datoteka s vama. Trebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.",
    "Password to access files shared to you by %1$s" : "Zaporka za pristupanje datotekama koju s vama dijeli %1$s",
    "Password to access files" : "Zaporka za pristupanje datotekama",
    "%s shared multiple files with \"%s\"." : "%s dijeli više datoteka s „%s“.",
    "%s shared multiple files with you." : "%s dijeli više datoteka s vama.",
    "Boot up" : "Pokreni",
    "Fresh installation status" : "Status svježe instalacije",
    "Building Local Database" : "Izgradnja lokalne baze podataka",
    "Testing Basic Circle Creation" : "Ispitivanje stvaranja osnovnog kruga",
    "Adding local users and moderators" : "Dodavanje lokalnih korisnika i moderatora",
    "Files" : "Datoteke",
    "This feature is not available for personal circles" : "Ova značajka nije dostupna za osobne krugove",
    "This member is not a moderator" : "Ovaj član nije moderator",
    "Insufficient privileges" : "Nedovoljne ovlasti",
    "This member does not exist" : "Ovaj član ne postoji",
    "Level cannot be changed for this type of member" : "Razina se ne može promijeniti za ovu vrstu člana",
    "You are already a member of this circle" : "Već ste član ovog kruga",
    "You have been blocked from this circle" : "Blokirani ste iz ovog kruga",
    "You are now a member of the Circle \"%2$s\"" : "Postali ste član kruga „%2$s”",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s vas je pozvao u krug „%2$s”",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s je poslao zahtjev za učlanjenje u krug „%2$s”",
    "Accept" : "Prihvati",
    "Refuse" : "Odbij",
    "Leave the circle" : "Napusti krug",
    "%s" : "%s",
    "%s owned by %s" : "%s u vlasništvu %s",
    "%s shared a file with you." : "%s dijeli datoteku s vama.",
    "Bring cloud-users closer together." : "Približite korisnike oblaka.",
    "No files in here" : "Nema datoteka",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "Circles" : "Krugovi",
    "Circles' files" : "Datoteke krugova",
    "Select circles to filter by" : "Odaberite krugove koje želite filtrirati",
    "No circles found" : "Nije pronađen nijedan krug",
    "Please select circles to filter by" : "Odaberite krugove koje želite filtrirati",
    "No files found for the selected circles" : "Nije pronađena nijedna datoteka za odabrane krugove",
    "You created the circle {circle}" : "Stvorili ste krug {circle}",
    "{author} created the circle {circle}" : "{author} je stvorio krug {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "O događajima koji se događaju u <strong>krugu</strong> čiji ste član",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Bilo koji važan događaj u <strong>krugu</strong> koji moderirate",
    "On global events happening in any <strong>Circle</strong>" : "O globalnim događajima koji pripadaju bilo kojem <strong>krugu</strong>",
    "Join Request" : "Zahtjev za pridruživanje",
    "Password Protected" : "Zaštićeno zaporkom",
    "Circle Invite" : "Poziv u krug",
    "Email Address" : "Adresa e-pošte",
    "Initialisation Nextcloud" : "Inicijalizacija Nextclouda",
    "Initialisation Circles App" : "Inicijalizacija aplikacije Circles",
    "Circle not found" : "Krug nije pronađen",
    "Circle not found " : "Krug nije pronađen ",
    "Federated link not found" : "Udružena poveznica nije pronađena",
    "The circle is not federated" : "Krug nije udruženi",
    "You cannot join this circle" : "Ne možete se pridružiti ovom krugu",
    "This member is the owner of the circle" : "Ovaj član je vlasnik kruga",
    "Personal Circle" : "Osobni krug",
    "You need a specify a type of circle" : "Trebate odrediti vrstu kruga",
    "A circle with that name exists" : "Postoji krug s tim nazivom",
    "This member is not the owner of the circle" : "Ovaj član nije vlasnik kruga",
    "This member is not an admin of the circle" : "Ovaj član nije administrator kruga",
    "Group contains too many members" : "Grupa ima previše članova",
    "This group does not exist" : "Ova grupa ne postoji",
    "This group is already linked to the circle" : "Ova je grupa već povezana s krugom",
    "You cannot edit level in a personal circle" : "Ne možete uređivati razinu u osobnom krugu",
    "Group cannot be set as owner of a circle" : "Grupa se ne može postaviti kao vlasnik kruga",
    "now" : "sada",
    "Email format is not valid" : "Format e-pošte nije važeći",
    "This contact is not available" : "Ovaj kontakt nije dostupan",
    "This item is already shared with this circle" : "Ova se stavka već dijeli s ovim krugom"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
